@@ -5,7 +5,7 @@ use warnings;
 package Type::Library::Compiler;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.007';
+our $VERSION   = '0.008';
 
 use Type::Library::Compiler::Mite -all;
 use B ();
@@ -182,7 +182,7 @@ BEGIN {
 	sub DOES {
 		return 1 if $_[1] eq 'Type::API::Constraint';
 		return 1 if $_[1] eq 'Type::Library::Compiler::TypeConstraint';
-		shift->DOES( @_ );
+		shift->SUPER::DOES( @_ );
 	}
 };
 
