@@ -3,13 +3,42 @@
     package Type::Library::Compiler;
     use strict;
     use warnings;
+    no warnings qw( once void );
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Type::Library::Compiler::Mite";
-    our $MITE_VERSION = "0.007003";
+    our $MITE_VERSION = "0.013000";
 
+    # Mite keywords
+    BEGIN {
+        my ( $SHIM, $CALLER ) =
+          ( "Type::Library::Compiler::Mite", "Type::Library::Compiler" );
+        (
+            *after, *around, *before,        *extends, *field,
+            *has,   *param,  *signature_for, *with
+          )
+          = do {
+
+            package Type::Library::Compiler::Mite;
+            no warnings 'redefine';
+            (
+                sub { $SHIM->HANDLE_after( $CALLER, "class", @_ ) },
+                sub { $SHIM->HANDLE_around( $CALLER, "class", @_ ) },
+                sub { $SHIM->HANDLE_before( $CALLER, "class", @_ ) },
+                sub { },
+                sub { $SHIM->HANDLE_has( $CALLER, field => @_ ) },
+                sub { $SHIM->HANDLE_has( $CALLER, has   => @_ ) },
+                sub { $SHIM->HANDLE_has( $CALLER, param => @_ ) },
+                sub { $SHIM->HANDLE_signature_for( $CALLER, "class", @_ ) },
+                sub { $SHIM->HANDLE_with( $CALLER, @_ ) },
+            );
+          };
+    }
+
+    # Mite imports
     BEGIN {
         require Scalar::Util;
+        *STRICT  = \&Type::Library::Compiler::Mite::STRICT;
         *bare    = \&Type::Library::Compiler::Mite::bare;
         *blessed = \&Scalar::Util::blessed;
         *carp    = \&Type::Library::Compiler::Mite::carp;
@@ -18,12 +47,35 @@
         *false   = \&Type::Library::Compiler::Mite::false;
         *guard   = \&Type::Library::Compiler::Mite::guard;
         *lazy    = \&Type::Library::Compiler::Mite::lazy;
+        *lock    = \&Type::Library::Compiler::Mite::lock;
         *ro      = \&Type::Library::Compiler::Mite::ro;
         *rw      = \&Type::Library::Compiler::Mite::rw;
         *rwp     = \&Type::Library::Compiler::Mite::rwp;
         *true    = \&Type::Library::Compiler::Mite::true;
+        *unlock  = \&Type::Library::Compiler::Mite::unlock;
     }
 
+    # Gather metadata for constructor and destructor
+    sub __META__ {
+        no strict 'refs';
+        my $class = shift;
+        $class = ref($class) || $class;
+        my $linear_isa = mro::get_linear_isa($class);
+        return {
+            BUILD => [
+                map { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
+                map { "$_\::BUILD" } reverse @$linear_isa
+            ],
+            DEMOLISH => [
+                map { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
+                map { "$_\::DEMOLISH" } @$linear_isa
+            ],
+            HAS_BUILDARGS        => $class->can('BUILDARGS'),
+            HAS_FOREIGNBUILDARGS => $class->can('FOREIGNBUILDARGS'),
+        };
+    }
+
+    # Standard Moose/Moo-style constructor
     sub new {
         my $class = ref( $_[0] ) ? ref(shift) : shift;
         my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
@@ -34,7 +86,8 @@
           : { ( @_ == 1 ) ? %{ $_[0] } : @_ };
         my $no_build = delete $args->{__no_BUILD__};
 
-        # Attribute: types
+        # Attribute types (type: Map[NonEmptyStr,Object])
+        # has declaration, file lib/Type/Library/Compiler.pm, line 17
         do {
             my $value =
               exists( $args->{"types"} )
@@ -81,16 +134,17 @@
             $self->{"types"} = $value;
         };
 
-        # Attribute: pod
+        # Attribute pod (type: Bool)
+        # has declaration, file lib/Type/Library/Compiler.pm, line 19
         do {
-            my $value = exists( $args->{"pod"} ) ? $args->{"pod"} : "1";
+            my $value = exists( $args->{"pod"} ) ? $args->{"pod"} : true;
             do {
                 my $coerced_value = do {
                     my $to_coerce = $value;
                     (
                         (
                             !ref $to_coerce
-                              and (!defined $to_coerce
+                              and ( !defined $to_coerce
                                 or $to_coerce eq q()
                                 or $to_coerce eq '0'
                                 or $to_coerce eq '1' )
@@ -102,7 +156,7 @@
                 };
                 (
                     !ref $coerced_value
-                      and (!defined $coerced_value
+                      and ( !defined $coerced_value
                         or $coerced_value eq q()
                         or $coerced_value eq '0'
                         or $coerced_value eq '1' )
@@ -113,7 +167,8 @@
             };
         };
 
-        # Attribute: destination_module
+        # Attribute destination_module (type: NonEmptyStr)
+        # has declaration, file lib/Type/Library/Compiler.pm, line 26
         croak "Missing key in constructor: destination_module"
           unless exists $args->{"destination_module"};
         (
@@ -138,7 +193,8 @@
           "destination_module", "NonEmptyStr";
         $self->{"destination_module"} = $args->{"destination_module"};
 
-        # Attribute: constraint_module
+        # Attribute constraint_module (type: NonEmptyStr)
+        # has declaration, file lib/Type/Library/Compiler.pm, line 38
         do {
             my $value =
               exists( $args->{"constraint_module"} )
@@ -162,7 +218,8 @@
             $self->{"constraint_module"} = $value;
         };
 
-        # Attribute: destination_filename
+        # Attribute destination_filename (type: NonEmptyStr)
+        # has declaration, file lib/Type/Library/Compiler.pm, line 47
         if ( exists $args->{"destination_filename"} ) {
             (
                 (
@@ -188,7 +245,10 @@
             $self->{"destination_filename"} = $args->{"destination_filename"};
         }
 
-        # Enforce strict constructor
+        # Call BUILD methods
+        $self->BUILDALL($args) if ( !$no_build and @{ $meta->{BUILD} || [] } );
+
+        # Unrecognized parameters
         my @unknown = grep not(
 /\A(?:constraint_module|destination_(?:filename|module)|pod|types)\z/
         ), keys %{$args};
@@ -196,18 +256,17 @@
           and croak(
             "Unexpected keys in constructor: " . join( q[, ], sort @unknown ) );
 
-        # Call BUILD methods
-        $self->BUILDALL($args) if ( !$no_build and @{ $meta->{BUILD} || [] } );
-
         return $self;
     }
 
+    # Used by constructor to call BUILD methods
     sub BUILDALL {
         my $class = ref( $_[0] );
         my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
         $_->(@_) for @{ $meta->{BUILD} || [] };
     }
 
+    # Destructor should call DEMOLISH methods
     sub DESTROY {
         my $self  = shift;
         my $class = ref($self) || $self;
@@ -228,42 +287,11 @@
         return;
     }
 
-    sub __META__ {
-        no strict 'refs';
-        no warnings 'once';
-        my $class = shift;
-        $class = ref($class) || $class;
-        my $linear_isa = mro::get_linear_isa($class);
-        return {
-            BUILD => [
-                map { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
-                map { "$_\::BUILD" } reverse @$linear_isa
-            ],
-            DEMOLISH => [
-                map   { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
-                  map { "$_\::DEMOLISH" } @$linear_isa
-            ],
-            HAS_BUILDARGS        => $class->can('BUILDARGS'),
-            HAS_FOREIGNBUILDARGS => $class->can('FOREIGNBUILDARGS'),
-        };
-    }
-
-    sub DOES {
-        my ( $self, $role ) = @_;
-        our %DOES;
-        return $DOES{$role} if exists $DOES{$role};
-        return 1            if $role eq __PACKAGE__;
-        return $self->SUPER::DOES($role);
-    }
-
-    sub does {
-        shift->DOES(@_);
-    }
-
-    my $__XS = !$ENV{MITE_PURE_PERL}
+    my $__XS = !$ENV{PERL_ONLY}
       && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
 
     # Accessors for constraint_module
+    # has declaration, file lib/Type/Library/Compiler.pm, line 38
     if ($__XS) {
         Class::XSAccessor->import(
             chained   => 1,
@@ -272,19 +300,21 @@
     }
     else {
         *constraint_module = sub {
-            @_ > 1
-              ? croak(
-                "constraint_module is a read-only attribute of @{[ref $_[0]]}")
-              : $_[0]{"constraint_module"};
+            @_ == 1
+              or croak(
+                'Reader "constraint_module" usage: $self->constraint_module()');
+            $_[0]{"constraint_module"};
         };
     }
 
     # Accessors for destination_filename
+    # has declaration, file lib/Type/Library/Compiler.pm, line 47
     sub destination_filename {
-        @_ > 1
-          ? croak(
-            "destination_filename is a read-only attribute of @{[ref $_[0]]}")
-          : (
+        @_ == 1
+          or croak(
+            'Reader "destination_filename" usage: $self->destination_filename()'
+          );
+        (
             exists( $_[0]{"destination_filename"} )
             ? $_[0]{"destination_filename"}
             : (
@@ -312,10 +342,11 @@
                     $default_value;
                 }
             )
-          );
+        );
     }
 
     # Accessors for destination_module
+    # has declaration, file lib/Type/Library/Compiler.pm, line 26
     if ($__XS) {
         Class::XSAccessor->import(
             chained   => 1,
@@ -324,14 +355,16 @@
     }
     else {
         *destination_module = sub {
-            @_ > 1
-              ? croak(
-                "destination_module is a read-only attribute of @{[ref $_[0]]}")
-              : $_[0]{"destination_module"};
+            @_ == 1
+              or croak(
+                'Reader "destination_module" usage: $self->destination_module()'
+              );
+            $_[0]{"destination_module"};
         };
     }
 
     # Accessors for pod
+    # has declaration, file lib/Type/Library/Compiler.pm, line 19
     sub pod {
         @_ > 1
           ? do {
@@ -340,7 +373,7 @@
                 (
                     (
                         !ref $to_coerce
-                          and (!defined $to_coerce
+                          and ( !defined $to_coerce
                             or $to_coerce eq q()
                             or $to_coerce eq '0'
                             or $to_coerce eq '1' )
@@ -351,7 +384,7 @@
             };
             (
                 !ref $value
-                  and (!defined $value
+                  and ( !defined $value
                     or $value eq q()
                     or $value eq '0'
                     or $value eq '1' )
@@ -365,6 +398,7 @@
     }
 
     # Accessors for types
+    # has declaration, file lib/Type/Library/Compiler.pm, line 17
     if ($__XS) {
         Class::XSAccessor->import(
             chained   => 1,
@@ -373,11 +407,29 @@
     }
     else {
         *types = sub {
-            @_ > 1
-              ? croak("types is a read-only attribute of @{[ref $_[0]]}")
-              : $_[0]{"types"};
+            @_ == 1 or croak('Reader "types" usage: $self->types()');
+            $_[0]{"types"};
         };
     }
 
+    # See UNIVERSAL
+    sub DOES {
+        my ( $self, $role ) = @_;
+        our %DOES;
+        return $DOES{$role} if exists $DOES{$role};
+        return 1            if $role eq __PACKAGE__;
+        if ( $INC{'Moose/Util.pm'}
+            and my $meta = Moose::Util::find_meta( ref $self or $self ) )
+        {
+            $meta->can('does_role') and $meta->does_role($role) and return 1;
+        }
+        return $self->SUPER::DOES($role);
+    }
+
+    # Alias for Moose/Moo-compatibility
+    sub does {
+        shift->DOES(@_);
+    }
+
     1;
 }
